var baseController = require("./controller");

var controllers = require("require-all")({
  dirname: process.cwd() + "/controllers",
  filter: /(.+controller)\.js$/,
  excludeDirs: /^\.(git|svn)$/,
  recursive: true
});

module.exports = {
  findContentController: function(contentTypeAlias, method = "get") {
    var controllerName = contentTypeAlias.toLowerCase() + "controller";
    var customController = controllers[controllerName];

    let controller = customController
      ? new customController()
      : new baseController();

    if (controller[method]) {
      return controller[method];
    } else {
      return controller.run;
    }
  },

  findCustomController: function(url, method = "get") {
    var controllerName =
      url
        .substring(1)
        .split("/")
        .join(".")
        .toLowerCase() + "controller";
    var controller = controllers[controllerName];

    if (!controller) {
      return undefined;
    }

    var handler = new controller();
    if (handler[method]) {
      return handler[method];
    } else {
      return handler.run;
    }
  }
};
